@@ -70,10 +70,6 @@ class VersionBumpData(Generic[T], metaclass=abc.ABCMeta):
   def post_init(self) -> None:
     pass
 
-  @abc.abstractmethod
-  def run_checks(self) -> int:
-    pass
-
   @abc.abstractmethod
   def get_snapshot_version(self) -> Version:
     pass
@@ -179,12 +175,6 @@ def do_bump(args: Args, data: VersionBumpData[AbstractProjectModel]) -> None:
   if not version_refs:
     sys.exit('error: no version refs found')
 
-  # Run checks.
-  if not args.skip_checks:
-    res = data.run_checks()
-    if res != 0:
-      sys.exit('error: checks failed')
-
   # Ensure the version is the same accross all refs.
   current_version = data.obj.get_version()
   is_inconsistent = any(parse_version(x.value) != current_version for x in version_refs)
